@@ -199,8 +199,9 @@ class AirHumidifierStatus(DeviceStatus):
 
         If water tank is full, depth is 125.
         """
-        if self.depth is not None and self.depth <= 125:
-            return int(self.depth / 1.25)
+        depth = self.data.get("depth")
+        if depth is not None and depth <= 125:
+            return int(depth / 1.25)
         return None
 
     @property
