@@ -87,7 +87,13 @@ from .fan import (
     MODEL_FAN_ZA3,
     MODEL_FAN_ZA4,
 )
-from .fan_miot import MODEL_FAN_1C, MODEL_FAN_P9, MODEL_FAN_P10, MODEL_FAN_P11
+from .fan_miot import (
+    MODEL_FAN_1C,
+    MODEL_FAN_P9,
+    MODEL_FAN_P10,
+    MODEL_FAN_P11,
+    MODEL_FAN_ZA5,
+)
 from .heater import MODEL_HEATER_MA1, MODEL_HEATER_ZA1
 from .powerstrip import MODEL_POWER_STRIP_V1, MODEL_POWER_STRIP_V2
 from .toiletlid import MODEL_TOILETLID_V1
@@ -187,6 +193,7 @@ DEVICE_MAP: Dict[str, Union[Type[Device], partial]] = {
     "dmaker-fan-p9": partial(FanMiot, model=MODEL_FAN_P9),
     "dmaker-fan-p10": partial(FanMiot, model=MODEL_FAN_P10),
     "dmaker-fan-p11": partial(FanMiot, model=MODEL_FAN_P11),
+    "zhimi-fan-za5": partial(FanMiot, model=MODEL_FAN_ZA5),
     "tinymu-toiletlid-v1": partial(Toiletlid, model=MODEL_TOILETLID_V1),
     "zhimi-airfresh-va2": partial(AirFresh, model=MODEL_AIRFRESH_VA2),
     "zhimi-airfresh-va4": partial(AirFresh, model=MODEL_AIRFRESH_VA4),
