@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*#
-from datetime import datetime, time, timedelta
+from datetime import datetime, time, timedelta, tzinfo
 from enum import IntEnum
 from typing import Any, Dict, List, Optional, Union
 
@@ -69,6 +69,21 @@ class VacuumStatus(DeviceStatus):
         # 'map_present': 1, 'in_cleaning': 3, 'in_returning': 0,
         # 'in_fresh_state': 0, 'lab_status': 1, 'water_box_status': 0,
         # 'fan_power': 102, 'dnd_enabled': 0, 'map_status': 3, 'lock_status': 0}]
+
+        # Example of S7 in charging mode
+        # new items: is_locating, water_box_mode, water_box_carriage_status,
+        # mop_forbidden_enable, adbumper_status, water_shortage_status,
+        # dock_type, dust_collection_status, auto_dust_collection, mop_mode, debug_mode
+        #
+        # [{'msg_ver': 2, 'msg_seq': 1839, 'state': 8, 'battery': 100,
+        # 'clean_time': 2311, 'clean_area': 35545000, 'error_code': 0,
+        # 'map_present': 1, 'in_cleaning': 0, 'in_returning': 0,
+        # 'in_fresh_state': 1, 'lab_status': 3, 'water_box_status': 1,
+        # 'fan_power': 102, 'dnd_enabled': 0, 'map_status': 3, 'is_locating': 0,
+        # 'lock_status': 0, 'water_box_mode': 202, 'water_box_carriage_status': 0,
+        # 'mop_forbidden_enable': 0, 'adbumper_status': [0, 0, 0],
+        # 'water_shortage_status': 0, 'dock_type': 0, 'dust_collection_status': 0,
+        # 'auto_dust_collection': 1,  'mop_mode': 300, 'debug_mode': 0}]
         self.data = data
 
     @property
@@ -175,6 +190,21 @@ class VacuumStatus(DeviceStatus):
         """Return True is water box is installed."""
         return "water_box_status" in self.data and self.data["water_box_status"] == 1
 
+    @property
+    def is_water_box_carriage_attached(self) -> Optional[bool]:
+        """Return True if water box carriage (mop) is installed, None if sensor not
+        present."""
+        if "water_box_carriage_status" in self.data:
+            return self.data["water_box_carriage_status"] == 1
+        return None
+
+    @property
+    def is_water_shortage(self) -> Optional[bool]:
+        """Returns True if water is low in the tank, None if sensor not present."""
+        if "water_shortage_status" in self.data:
+            return self.data["water_shortage_status"] == 1
+        return None
+
     @property
     def got_error(self) -> bool:
         """True if an error has occured."""
@@ -192,7 +222,7 @@ class CleaningSummary(DeviceStatus):
         #  1487894400, 1487808000, 1487548800 ] ],
         #  "id": 1 }
         # newer models return a dict
-        if type(data) is list:
+        if isinstance(data, list):
             self.data = {
                 "clean_time": data[0],
                 "clean_area": data[1],
@@ -242,7 +272,7 @@ class CleaningDetails(DeviceStatus):
         # start, end, duration, area, unk, complete
         # { "result": [ [ 1488347071, 1488347123, 16, 0, 0, 0 ] ], "id": 1 }
         # newer models return a dict
-        if type(data) is list:
+        if isinstance(data, list):
             self.data = {
                 "begin": data[0],
                 "end": data[1],
@@ -309,6 +339,7 @@ class ConsumableStatus(DeviceStatus):
         #  'sensor_dirty_time': 3798,
         # 'side_brush_work_time': 32454,
         #  'main_brush_work_time': 32454}]}
+        # TODO this should be generalized to allow different time limits
         self.data = data
         self.main_brush_total = timedelta(hours=300)
         self.side_brush_total = timedelta(hours=200)
@@ -386,7 +417,7 @@ class Timer(DeviceStatus):
     the creation time.
     """
 
-    def __init__(self, data: List[Any], timezone: "datetime.tzinfo") -> None:
+    def __init__(self, data: List[Any], timezone: tzinfo) -> None:
         # id / timestamp, enabled, ['<cron string>', ['command', 'params']
         # [['1488667794112', 'off', ['49 22 * * 6', ['start_clean', '']]],
         #  ['1488667777661', 'off', ['49 21 * * 3,4,5,6', ['start_clean', '']]
@@ -394,10 +425,11 @@ class Timer(DeviceStatus):
         self.data = data
         self.timezone = timezone
 
+        # ignoring the type here, as the localize is not provided directly by datetime.tzinfo
+        localized_ts = timezone.localize(datetime.now())  # type: ignore
+
         # Initialize croniter to cause an exception on invalid entries (#847)
-        self.croniter = croniter(
-            self.cron, start_time=timezone.localize(datetime.now())
-        )
+        self.croniter = croniter(self.cron, start_time=localized_ts)
 
     @property
     def id(self) -> int:
